@@ -258,7 +258,7 @@ class AwlQuery
         if ( isset($matches[4]) && $matches[4] != '' ) $dbuser = $matches[4];
         if ( isset($matches[6]) && $matches[6] != '' ) $dbpass = $matches[6];
       }
-      if ( $new_connection = new AwlDatabase( $dsn, $dbuser, $dbpass, $options ) ) break;
+      if ( ! $new_connection = new AwlDatabase( $dsn, $dbuser, $dbpass, $options ) ) return;
     }
     $this->connection = $new_connection;
     return $new_connection;
